==> db4o-5.0-mono.tar.gz: db4o-5.0/src/core/src/core/com/db4o/inside/freespace/FreespaceIx.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.inside.freespace
{
	internal abstract class FreespaceIx
	{
		internal com.db4o.inside.ix.Index4 _index;

		internal com.db4o.inside.ix.IndexTransaction _indexTrans;

		internal com.db4o.inside.ix.IxTraverser _traverser;

		internal com.db4o.inside.freespace.FreespaceVisitor _visitor;

		internal FreespaceIx(com.db4o.YapFile file, com.db4o.MetaIndex metaIndex)
		{
			_index = new com.db4o.inside.ix.Index4(file.getSystemTransaction(), new com.db4o.YInt
				(file), metaIndex, false);
			_indexTrans = _index.globalIndexTransaction();
		}

		internal abstract void add(int address, int length);

		internal abstract int address();

		public virtual void debug()
		{
		}

		internal virtual void find(int val)
		{
			_traverser = new com.db4o.inside.ix.IxTraverser();
			_traverser.findBoundsExactMatch(val, (com.db4o.inside.ix.IxTree)_indexTrans.getRoot
				());
		}

		internal abstract int length();

		internal virtual bool match()
		{
			_visitor = new com.db4o.inside.freespace.FreespaceVisitor();
			_traverser.visitMatch(_visitor);
			return _visitor.visited();
		}

		internal virtual bool preceding()
		{
			_visitor = new com.db4o.inside.freespace.FreespaceVisitor();
			_traverser.visitPreceding(_visitor);
			return _visitor.visited();
		}

		internal abstract void remove(int address, int length);

		internal virtual bool subsequent()
		{
			_visitor = new com.db4o.inside.freespace.FreespaceVisitor();
			_traverser.visitSubsequent(_visitor);
			return _visitor.visited();
		}
	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/core/src/core/com/db4o/inside/freespace/FreespaceIx.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.inside.freespace
{
	internal abstract class FreespaceIx
	{
		internal com.db4o.inside.ix.Index4 _index;

		internal com.db4o.inside.ix.IndexTransaction _indexTrans;

		internal com.db4o.inside.ix.IxTraverser _traverser;

		internal com.db4o.inside.freespace.FreespaceVisitor _visitor;

		internal FreespaceIx(com.db4o.YapFile file, com.db4o.MetaIndex metaIndex)
		{
			_index = new com.db4o.inside.ix.Index4(file.GetSystemTransaction(), new com.db4o.YInt
				(file), metaIndex, false);
			_indexTrans = _index.GlobalIndexTransaction();
		}

		internal abstract void Add(int address, int length);

		internal abstract int Address();

		public virtual void Debug()
		{
		}

		internal virtual void Find(int val)
		{
			_traverser = new com.db4o.inside.ix.IxTraverser();
			_traverser.FindBoundsExactMatch(val, (com.db4o.inside.ix.IxTree)_indexTrans.GetRoot
				());
		}

		internal abstract int Length();

		internal virtual bool Match()
		{
			_visitor = new com.db4o.inside.freespace.FreespaceVisitor();
			_traverser.VisitMatch(_visitor);
			return _visitor.Visited();
		}

		internal virtual bool Preceding()
		{
			_visitor = new com.db4o.inside.freespace.FreespaceVisitor();
			_traverser.VisitPreceding(_visitor);
			return _visitor.Visited();
		}

		internal abstract void Remove(int address, int length);

		internal virtual bool Subsequent()
		{
			_visitor = new com.db4o.inside.freespace.FreespaceVisitor();
			_traverser.VisitSubsequent(_visitor);
			return _visitor.Visited();
		}
	}
}
